#!/usr/bin/env python
#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005    Shuttleworth Foundation,
#                       Brian Sutherland
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
SchoolTool LDAP plugin setup script.
"""

# Check python version
import sys
if sys.version_info < (2, 4):
    print >> sys.stderr, '%s: need Python 2.4 or later.' % sys.argv[0]
    print >> sys.stderr, 'Your python is %s' % sys.version
    sys.exit(1)

import pkg_resources
pkg_resources.require("setuptools>=0.6a11")

import os
from setuptools import setup, find_packages

version = open("version.txt").read().strip()
if version.endswith("dev"):
    svnversion = os.popen('svnversion').read().strip()
    versions = svnversion.split(':')
    if len(versions) > 1:
        sys.exit("Please run `svn up` before running this script.")
    max_version = versions[0]
    if max_version.endswith("M"):
        sys.exit("You have uncommited changes. "
                 "Please commit them before running this script.")
    version += "_r" + max_version

# Setup LDAP
setup(
    name="schooltool.ldap",
    description="SchoolTool LDAP authentication plugin.",
    long_description="""TODO""",
    version=version,
    url='http://www.schooltool.org',
    license="GPL",
    maintainer="SchoolTool development team",
    maintainer_email="schooltool-dev@schooltool.org",
    platforms=["any"],
    classifiers=["Development Status :: 4 - Beta",
    "Environment :: Web Environment",
    "Intended Audience :: End Users/Desktop",
    "License :: OSI Approved :: GNU General Public License (GPL)",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Zope",
    "Topic :: Education",
    "Topic :: Office/Business :: Scheduling"],
    package_dir={'': 'src'},
    namespace_packages=["schooltool"],
    packages=find_packages('src'),
    install_requires=['schooltool',
                      'ldapadapter >= 0.6',
                      'ldappas >= 0.6',
                      'python-ldap',
                      'setuptools'],
    dependency_links=['http://svn.kmrc.de/download/distribution/',
                      'http://ftp.schooltool.org/schooltool/releases/nightly/',
                      'http://ftp.schooltool.org/schooltool/eggs/3.4/'],
    entry_points = """
    [schooltool.plugin_configuration]
    schooltool.ldap = schooltool.ldap
    """,
    include_package_data=True,
    zip_safe=False
    )
