#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
LDAP authentication plugin configuration.
"""
from ldappas.interfaces import ILDAPAuthentication
from ldappas.authentication import LDAPAuthentication
from ldapadapter.utility import LDAPAdapter
from ldapadapter.interfaces import ILDAPAdapter

from zope.component import provideUtility


def handle_configuration(options, context):
    if options.config.ldap_authentication:
        context.provideFeature('ldap_authentication')

        config = options.config.ldap_authentication
        ldapAdapter = LDAPAdapter(config.host,
                                  config.port,
                                  config.bind_dn,
                                  config.bind_password)
        provideUtility(ldapAdapter, ILDAPAdapter, name='SchoolToolLDAP')

        ldapAuthentication = LDAPAuthentication()
        ldapAuthentication.adapterName = 'SchoolToolLDAP'

        for attr in ['searchBase', 'searchScope', 'groupsSearchBase',
                     'groupsSearchScope', 'loginAttribute', 'principalIdPrefix',
                     'idAttribute', 'titleAttribute', 'groupIdAttribute',
                     'groupsAttribute']:
            value = getattr(config, attr.lower())
            setattr(ldapAuthentication, attr, value)

        provideUtility(ldapAuthentication, ILDAPAuthentication)

        context.provideFeature('authentication')


def get_configuration():
    return ("""
<import package="schooltool.ldap" />

<section type="ldap_authentication" name="*" required="no" attribute="ldap_authentication">
  <description>
    Configuration for LDAP authentication plugin.
  </description>
  <example>
    &lt;ldap_authentication&gt;
      host localhost
      port 389
    &lt;/ldap_authentication&gt;
  </example>
</section>

""", handle_configuration)
